# NcatBot

---
![img.png](https://socialify.git.ci/liyihao1110/NcatBot/image?description=1&forks=1&issues=1&language=1&logo=https%3A%2F%2Fdocs.ncatbot.xyz%2Fimages%2Flogo.png&name=1&owner=1&pulls=1&stargazers=1&theme=Auto)
<h2 align="center">基于 NapCat 的 QQ 机器人 Python 快速开发框架 (SDK)</h2>
<p align="center">
	<a href="https://pypi.org/project/ncatbot/"><img src="https://img.shields.io/pypi/v/ncatbot"></a>
  <a><img src="https://img.shields.io/badge/License-NcatBot License-green.svg"></a>
    <a href="https://qm.qq.com/q/CHbzJ2LH4k"><img src="https://img.shields.io/badge/官方群聊-201487478-brightgreen.svg"></a>
    <a href="https://qm.qq.com/q/S2zIli2qsu"><img src="https://img.shields.io/badge/基于ncatbot开发的小机器人-3786498591-brightgreen.svg"></a>
    <a href="https://ippclub.org"><img src="https://img.shields.io/badge/I%2B%2B%E4%BF%B1%E4%B9%90%E9%83%A8-%E8%AE%A4%E8%AF%81-11A7E2?logo=data%3Aimage%2Fsvg%2Bxml%3Bcharset%3Dutf-8%3Bbase64% % %2BPHBhdGggZD0ibTEyNCAxMDAgMjItNDEgMTIgMjctMzQgMTRaIiBzdHlsZT0iZmlsbDojNGUyNzVhO2ZpbGwtcnVsZTpub256ZXJvIi8%2BPHBhdGggZD0ibTEwNiA2MCA0MS0xLTIzIDQxLTE4LTQwWiIgc3R5bGU9ImZpbGw6IzdiMTI4NTtmaWxsLXJ1bGU6bm9uemVybyIvPjxwYXRoIGQ9Im0xMDggMjA0IDMxLTQ4aC0zMXY0OFoiIHN0eWxlPSJmaWxsOiNiYTAwNzc7ZmlsbC1ydWxlOm5vbnplcm8iLz48cGF0aCBkPSJtNjUgMjc0IDMzLTUySDBsNjUgNTJaIiBzdHlsZT0iZmlsbDojZWY3YTAwO2ZpbGwtcnVsZTpub256ZXJvIi8%2BPHBhdGggZD0iTTc3IDI3NGg2N2wtNDAtNDUtMjcgNDVaIiBzdHlsZT0iZmlsbDojYTgxZTI0O2ZpbGwtcnVsZTpub256ZXJvIi8%2BPHBhdGggZD0iTTE2NyAyMjJoNThsLTM0IDUyLTI0LTUyWiIgc3R5bGU9ImZpbGw6IzExYTdlMjtmaWxsLXJ1bGU6bm9uemVybyIvPjxwYXRoIGQ9Im0yNzAgMjc0LTQ0LTUyLTM1IDUyaDc5WiIgc3R5bGU9ImZpbGw6IzA1N2NiNztmaWxsLXJ1bGU6bm9uemVybyIvPjxwYXRoIGQ9Ik0yNzUgNTVoLTU3VjBoMjV2MzFoMzJ2MjRaIiBzdHlsZT0iZmlsbDojZGUwMDVkO2ZpbGwtcnVsZTpub256ZXJvIi8%2BPHBhdGggZD0iTTE4NSAzMWg1N3Y1NWgtMjVWNTVoLTMyVjMxWiIgc3R5bGU9ImZpbGw6I2M1MTgxZjtmaWxsLXJ1bGU6bm9uemVybyIvPjwvc3ZnPg%3D%3D&labelColor=fff"></a>
</p>

NcatBot 是 **[NapCat](https://github.com/NapNeko/NapCatQQ)** 的 Python SDK, 它提供了一套方便易用的 Python 接口用于开发基于 NapCat 的项目——也就是 QQ 机器人.

## 如何使用

### 用户使用

**不要下载 .zip 压缩包!!!**

前往 [Release](https://github.com/liyihao1110/ncatbot/releases) 下载 `main.exe`, 双击执行.

**不要或者删除 `main.exe` 生成的 `ncatbot` 文件夹**, 第一次执行后也**不要移动 `ncatbot` 文件夹或者 `main.exe`**.

### 开发者使用

请**认真阅读**[文档](https://docs.ncatbot.xyz/), **严格**按照文档中说明正确安装和使用 NcatBot.

[插件仓库地址](https://github.com/ncatbot/NcatBot-Plugins).

## 更新进度

---
[![木子/ncatbot](https://gitee.com/li-yihao0328/nc_bot/widgets/widget_card.svg?colors=ffffff,1e252b,323d47,455059,d7deea,99a0ae)](https://gitee.com/li-yihao0328/nc_bot)

## 欢迎来玩

[是 QQ 群哦喵~](https://qm.qq.com/q/L6XGXYqL86)

## 获取帮助

- 遇到任何困难时, 请先按照以下顺序尝试自己解决:
  1. **仔细阅读**[文档](https://docs.ncatbot.xyz/).
  2. 询问 [DeepSeek](https://chat.deepseek.com), [Kimi](https://kimi.ai) 等人工智能.
  3. 搜索本项目的 [Issue 列表](https://github.com/liyihao1110/ncatbot/issues).

- 如果以上方法都无法解决你的问题, 那么:

  也可以[进群](https://qm.qq.com/q/L6XGXYqL86)提问.

## 联系我们

作者: [最可爱的木子喵~](https://gitee.com/li-yihao0328)

邮箱: lyh_02@foxmail.com


## 贡献者们

---
<a href="https://github.com/liyihao1110/ncatbot/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=liyihao1110/ncatbot" />
</a>

如果你有好的 Idea, 欢迎提 Issue 和 PR!

## 致谢

---
感谢 [NapCat](https://github.com/NapNeko/NapCatQQ) 提供底层接口.

感谢 [IppClub](https://github.com/IppClub) 的宣传支持.
